<?php

namespace App\DataTables;

use App\Models\Customer;
use Yajra\DataTables\DataTables;

class CustomerDataTable
{
    public static function list($request)
    {
        $model = Customer::with('customerBillingPeriod.billingPeriod')
            ->with('customerBillingCompany.billingCompany');

            return DataTables::of($model)
            ->addColumn('reseller', function ($model) {
                if ($model->is_reseller) return '<span class="badge badge-success">Reseller</span>';
            })
            ->addColumn('actions', function ($model) {
                $html  = '';
                $html .=  '<a href="javascript:void(0)" data-url="' . route('customers.edit', $model->id) . '" class="load-modal" title="Edit">
                            <i class="anticon anticon-form font-size-18"></i>
                        </a>';
                $html .=    '<a href="javascript:void(0)" class="delete custom-modal" data-table="customer-table" title="Delete"
                            data-title="Delete Reseller" data-url="' . route('customers.destroy', $model->id) . '"
                            data-msg="Are you sure want to delete?" data-method="delete"
                            data-action-btn="Delete" data-loading-text="Deleting..."
                            data-action="' . route('customers.destroy', $model->id) . '">
                            <i class="anticon anticon-delete font-size-18 text-danger"></i>
                        </a>';
                return $html;
            })
            ->addColumn('billing_period', function ($model) {
                return $model->customerBillingPeriod->billingPeriod->billing_period ?? 'Billing Period Not Found';
            })
            ->addColumn('billing_company', function ($model) {

                if(isset($model->customerBillingCompany->billingCompany)){
                    $companyName = $model->customerBillingCompany->billingCompany->company_name ?? 'Company Not Found';
                }else{
                   return  $companyName = 'Company Not Found';
                }
                $html = '<a class="load-modal" href="javascript:void(0)"
                    data-url="' . route('billing-companies.show', $model->customerBillingCompany->billingCompany->id) . '" >' . $companyName . '</a>';

                return $html;
            })
            ->rawColumns(['actions', 'billing_period', 'billing_company', 'reseller'])
            ->addIndexColumn()
            ->make(true);


    }
}
