<?php

namespace App\DataTables;

use App\Models\Zone;
use Yajra\DataTables\DataTables;

class ZoneDataTable
{
    public static function list($request, $service_type_id)
    {
        $model = Zone::where(['service_type_id' => $service_type_id])->with('zonePostalCodes');
      
        return DataTables::of($model)

        ->addColumn('actions', function ($model) {
            $html  = '';
            $html .=  '<a href="javascript:void(0)" data-url="' . route('zones.edit', $model->id) . '" class="load-modal" title="Edit">
                        <i class="anticon anticon-form font-size-18"></i>
                    </a>';
            $html .=    '<a href="javascript:void(0)" class="delete custom-modal" data-table="zone-table" title="Delete"
                        data-title="Delete Zone" data-url="' . route('zones.destroy', $model->id) . '"
                        data-msg="Are you sure want to delete?" data-method="delete"
                        data-action-btn="Delete" data-loading-text="Deleting..."
                        data-action="' . route('zones.destroy', $model->id) . '">
                        <i class="anticon anticon-delete font-size-18 text-danger"></i>
                    </a>';
            return $html;
        })

        ->addColumn('countries', function ($model) {
            $html = '<div class="">';
            $zonePostalCodes  = $model->zonePostalCodes;

            if($zonePostalCodes){
                foreach($zonePostalCodes as $zonePostalCode){
                    $country = '<div class="my-4 border-bottom text-center text-wrap">';
                        $country .= $zonePostalCode->country->iso ?? '&nbsp;&nbsp;&nbsp;';
                    $country .= '</div>';
                    $html .=  $country;
                }
            }

            $html .= '</div>';
            return $html;
        })

        ->addColumn('included_postcode', function ($model) {
            $html = '<div class="">';
            $zonePostalCodes  = $model->zonePostalCodes;

            if($zonePostalCodes){
                foreach($zonePostalCodes as $zonePostalCode){
                    $incl = '<div class="my-4 border-bottom text-wrap" style="width: 400px !important;">';
                        $incl .= $zonePostalCode->incl ?? '&nbsp;';
                    $incl .= '</div>';
                    $html .= $incl;
                }
            }
            $html .= '</div>';

            return $html;
        })
        ->addColumn('excluded_postcode', function ($model) {
            $html = '<div class="">';
            $zonePostalCodes  = $model->zonePostalCodes;

            if($zonePostalCodes){
                foreach($zonePostalCodes as $zonePostalCode){
                    $excl = '<div class="my-4 border-bottom text-wrap" style="width: 400px !important;">';
                        $excl .= $zonePostalCode->excl ?? '&nbsp;';
                    $excl .= '</div>';

                    $html .= $excl;
                }
            }
            $html .= '</div>';

            return $html;
        })
        ->rawColumns(['actions','countries','included_postcode','excluded_postcode'])
        ->addIndexColumn()
        ->setRowClass(function ($model) {
            return 'align-top';
        })
        ->make(true);


    }
}
