@extends('layouts.app')
@section('page-title', 'Customer Service Price')

@section('page-header')
    <div class="page-header">
        <div class="row">
            <div class="col-6">
                <h4 class="header-title">Customer Service Prices</h4>
            </div>
            <div class="col-6">
            </div>
        </div>
    </div>
@endsection

@section('breadcrumb')
    <div class="page-header">
        <div class="header-sub-title">
            <nav class="breadcrumb breadcrumb-dash">
                <a href="{{ route('home') }}" class="breadcrumb-item">Dashboard</a>
                <a href="{{ route('service-prices.index') }}" class="breadcrumb-item">Service Prices</a>
                <a href="{{ route('customer-service-prices.index') }}" class="breadcrumb-item">Customer Service
                    Prices</a>
                <a href="{{ route('customer-service-prices.list', [$courier_service->id, $customer->id]) }}"
                    class="breadcrumb-item"><b class="text-capitalize"> {{ $customer->company_name }} </b> - {{ $courier_service->courier->name ?? '' }}
                    > {{ $courier_service->name ?? '' }}</a>
            </nav>''
        </div>
    </div>
@endsection

@section('body')
    <div class="card">
        <div class="card-body">
            <div class="d-flex align-items-center justify-content-between m-b-15">
                <h4>Customer Service Prices &nbsp;
                    <small class="badge tag-primary float-right mb-0" style="font-size: 13px;">
                        <b class="text-capitalize">  {{ $customer->company_name }} </b> - {{ $courier_service->courier->name ?? '' }}
                        > {{ $courier_service->name ?? '' }}
                    </small>

                </h4>
                @if (count($zones) && count($weight_classes))
                    <div class="m-2">
                        <a class="btn btn-primary float-right" href="javascript:void(0)" data-url="" data-toggle="modal"
                            data-target="#bulk-change-modal">
                        
                                @if(isset($customer_price_bulk_change))
                                    {{ $customer_price_bulk_change->percentage }}<i class="anticon anticon-percentage"></i> 
                                    {{ $customer_price_bulk_change->type == 0 ? 'Margin' : 'Markup' }}
                                @else
                                    <i class="anticon anticon-percentage"></i>  Bulk Change
                                @endif
                        
                        </a>
                    </div>
                @endif
            </div>

            <div class="m-t-50">
                <table id="service-table" class="table table-bordered" data-url="">
                    <thead>
                        <tr>
                            @if (count($zones) && count($weight_classes))
                                <th width="10%" class="text-center">
                                    <a href="javascript:;">
                                        <i class="anticon anticon-eye font-size-18 text-dark" id="show-service-prices"
                                            title="Show Price"></i>
                                    </a>
                                </th>
                                @foreach ($zones as $zone)
                                    <th class="text-capitalize">{{ $zone->zone_name }}</th>
                                @endforeach
                            @elseif(!count($weight_classes))
                                <th width="90%" class="text-danger text-center"> Weight classes not available</th>
                            @elseif(!count($zones))
                                <th width="90%" class="text-danger text-center"> Zones not available</th>
                            @endif
                        </tr>
                    </thead>
                    <tbody>
                        @if (count($weight_classes) && count($zones))
                            @foreach ($weight_classes as $weight_class)
                                <tr>
                                    <th class="text-capitalize text-center">{{ $weight_class->weight_class_name }}</th>
                                    @if (count($zones))
                                        @foreach ($zones as $zone)
                                            <td class="text-capitalize ">
                                                <span class="service-prices ml-5" style="display: none;">
                                                    {{-- <i class="fa fa-solid fa-euro-sign"></i> --}}
                                                    {{ $service_prices[$zone->id][$weight_class->id] ?? 0 }}
                                                </span>
                                                <div class="input-group mb-3" style="width: 130px;">
                                                    <div class="input-group-prepend">
                                                        <span class="input-group-text" id="basic-addon1">
                                                            {{ $courier_service->currency->currency_symbol ?? '' }}
                                                        </span>
                                                    </div>
                                                    <input class="form-control d-inline-block"
                                                        name="service_price[{{ $zone->id }}][{{ $weight_class->id }}]"
                                                        value="{{ $customer_service_prices[$zone->id][$weight_class->id] ?? 0 }}" />
                                                </div>
                                            </td>
                                        @endforeach
                                    @endif
                                </tr>
                            @endforeach
                        @endif
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="modal" id="bulk-change-modal">
        <div class="modal-dialog modal-md">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">
                      Bulk Change - 
                     
                            {{-- {{ $courier_service->courier->name ?? '' }} >  --}}
                            {{ $courier_service->name ?? '' }} 
                            Prices for {{ $customer->company_name }}
                    </h5>
                    <button type="button" class="close" data-dismiss="modal">
                        <i class="anticon anticon-close"></i>
                    </button>
                </div>
                <form class="form-horizontal" id="ajax-form" data-redirection="{{ url()->current() }}" action="{{ route('customer-service-prices.bulk-change') }} ">
                    <div class="modal-body">
                        @csrf
                        
                        <input type="hidden" value="{{ $customer->id }}" name="customer_id" id="customer_id">
                        <input type="hidden" value="{{ $courier_service->id }}" name="courier_service_id"
                            id="courier_service_id">
                        <div role="group" class="mb-4 btn-group">
                            <button type="button" id="margin-btn" class="btn btn-primary active pb-4 margin-btn">Margin</button>
                            <button type="button" id="markup-btn" class="btn btn-primary pb-4 markup-btn" min="0">Markup</button>
                        </div>
                        <div id="margin-tab" > 
                            <div class="form-group">
                                <label for="">Percent Margin</label>
                                <input type="number" class="form-control" name="percent_margin" id="percent_margin_input"
                                    placeholder="Enter Percent Margin" autocomplete="off" max="99" min="0" required>
                            </div>
                            <div class="alert alert-success" id="margin-alert">
                                Notice: the value is calculated as price / (1 - (percent / 100)). For example, if you submit
                                '25' and have defined your price as '£10', the calculation is 10 / (1 - 0.25) = £13.33
                            </div>
                        </div>
                        <div id="markup-tab" style="display:none">
                            <div class="form-group">
                                <label for="">Percent Markup</label>
                                <input type="number" class="form-control" name="percent_markup"  id="percent_markup_input"
                                    placeholder="Enter Percent Markup"  autocomplete="off" >
                            </div>
                            <div class="alert alert-success" id="markup-alert">
                                Notice: the percent is *added* onto your 'my prices' settings for this service. For example,
                                if you submit '25' and have defined your price as '£1', the customer price will be '£1.25'
                            </div>
                        </div>

                        <div class="alert alert-warning ">
                            Notice: this function will only work if all prices are defined in my-prices
                        </div>

                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-danger action-btn" data-loading-text="">Submit</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('js')
    <script src="{{ asset('js/customer_service_prices.js') }}"></script>
    <script>

        $(document).on('click', '#markup-btn', function () {

            $(this).addClass('active');
            $('#margin-btn').removeClass('active');

            $('#percent_margin_input').prop('required', false);
            $('#percent_markup_input').prop('required', true);

            $('#percent_markup_input').removeAttr('disabled');
            $('#percent_margin_input').attr('disabled', 'disabled');

            $('#markup-tab').show();
            $('#margin-tab').hide();
        });

        $(document).on('click', '#margin-btn', function () {

            $(this).addClass('active');
            $('#markup-btn').removeClass('active');

            $('#percent_margin_input').prop('required', true);
            $('#percent_markup_input').prop('required', false);

            $('#percent_margin_input').removeAttr('disabled');
            $('#percent_markup_input').attr('disabled', 'disabled');

            // $('#percent_margin_input').prop('disabled', false);
            // $('#percent_markup_input').prop('disabled', true);

            $('#markup-tab').hide();
            $('#margin-tab').show();
        });

    </script>
@endpush
